@@ -287,6 +287,11 @@ class fusionDB:
             }
         )
 
+        print('fusionDB.add_slide:')
+        print(new_item)
+        print(slide_id)
+        print(f'len(annotations): {len(annotations)}')
+
         for ann_idx, ann in enumerate(annotations):
             # Adding layer
             new_layer = self.get_create(
@@ -297,6 +302,7 @@ class fusionDB:
                     'item': slide_id
                 }
             )
+            print(f'new_layer: {new_layer}')
 
             if 'image_path' in ann:
                 # Adding image overlay layer
@@ -405,6 +411,8 @@ class fusionDB:
                 }
             }
         )
+        print('fusionDB.get_item_annotations:')
+        print(item_layers)
 
         for l in item_layers:
             layer_name = l.get('name')
